aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/symbian/symbian-fs.cpp
diff options
context:
space:
mode:
authorMax Horn2008-10-02 16:58:59 +0000
committerMax Horn2008-10-02 16:58:59 +0000
commitc7fde102e325b423b1b153a78f7544697c052b72 (patch)
tree051aa4e66c66a20fa52fbb771328df5ea8d4790a /backends/fs/symbian/symbian-fs.cpp
parent31be8a6b3f22880378db870600b29906135c8ef5 (diff)
downloadscummvm-rg350-c7fde102e325b423b1b153a78f7544697c052b72.tar.gz
scummvm-rg350-c7fde102e325b423b1b153a78f7544697c052b72.tar.bz2
scummvm-rg350-c7fde102e325b423b1b153a78f7544697c052b72.zip
Renamed FilesystemNode -> FSNode
svn-id: r34716
Diffstat (limited to 'backends/fs/symbian/symbian-fs.cpp')
-rw-r--r--backends/fs/symbian/symbian-fs.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/backends/fs/symbian/symbian-fs.cpp b/backends/fs/symbian/symbian-fs.cpp
index 1c6d8435a9..74b7c28873 100644
--- a/backends/fs/symbian/symbian-fs.cpp
+++ b/backends/fs/symbian/symbian-fs.cpp
@@ -37,9 +37,9 @@
/**
* Implementation of the ScummVM file system API based on POSIX.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemNode.
*/
-class SymbianFilesystemNode : public AbstractFilesystemNode {
+class SymbianFilesystemNode : public AbstractFSNode {
protected:
Common::String _displayName;
Common::String _path;
@@ -75,9 +75,9 @@ public:
virtual bool isReadable() const { return access(_path.c_str(), R_OK) == 0; } //FIXME: this is just a stub
virtual bool isWritable() const { return access(_path.c_str(), W_OK) == 0; } //FIXME: this is just a stub
- virtual AbstractFilesystemNode *getChild(const Common::String &n) const;
+ virtual AbstractFSNode *getChild(const Common::String &n) const;
virtual bool getChildren(AbstractFSList &list, ListMode mode, bool hidden) const;
- virtual AbstractFilesystemNode *getParent() const;
+ virtual AbstractFSNode *getParent() const;
virtual Common::SeekableReadStream *openForReading();
virtual Common::WriteStream *openForWriting();
@@ -133,7 +133,7 @@ SymbianFilesystemNode::SymbianFilesystemNode(const Common::String &path) {
}
}
-AbstractFilesystemNode *SymbianFilesystemNode::getChild(const Common::String &n) const {
+AbstractFSNode *SymbianFilesystemNode::getChild(const Common::String &n) const {
assert(_isDirectory);
Common::String newPath(_path);
@@ -216,8 +216,8 @@ bool SymbianFilesystemNode::getChildren(AbstractFSList &myList, ListMode mode, b
entry._isDirectory = fileentry.IsDir();
// Honor the chosen mode
- if ((mode == Common::FilesystemNode::kListFilesOnly && entry._isDirectory) ||
- (mode == Common::FilesystemNode::kListDirectoriesOnly && !entry._isDirectory))
+ if ((mode == Common::FSNode::kListFilesOnly && entry._isDirectory) ||
+ (mode == Common::FSNode::kListDirectoriesOnly && !entry._isDirectory))
continue;
myList.push_back(new SymbianFilesystemNode(entry));
@@ -229,7 +229,7 @@ bool SymbianFilesystemNode::getChildren(AbstractFSList &myList, ListMode mode, b
return true;
}
-AbstractFilesystemNode *SymbianFilesystemNode::getParent() const {
+AbstractFSNode *SymbianFilesystemNode::getParent() const {
SymbianFilesystemNode *p =NULL;
// Root node is its own parent. Still we can't just return this
@@ -37,9 +37,9 @@
* Implementation of the ScummVM file system API based on POSIX.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemNode.
+ * Parts of this class are documented in the base interface class, AbstractFSNode.
*/